@@ -84,7 +84,7 @@ def parse(html: str, p: Product, include: Sequence = None):
 
 
 def parse_product_asin(p: Product, selector: parsel.Selector = None):
-    p.product_asin = selector.re_first(r'"productAsin":"(.+?)"')
+    p.product_asin = selector.re_first(r'"currentAsin" : "(.+?)"')
 
 
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
